@@ -1,7 +1,7 @@
 import time
 from typing import Union, Optional
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from statsig.statsig_errors import StatsigValueError
 from statsig.statsig_user import StatsigUser
 
@@ -18,7 +18,7 @@ class StatsigEvent:
     value: Union[str, int, None] = None
     metadata: Optional[dict] = None
     _secondary_exposures: Optional[list] = None
-    _time: int = round(time.time() * 1000)
+    _time: int = field(default_factory=lambda: round(time.time() * 1000))
 
     def __post_init__(self):
         if self.user is None or not isinstance(self.user, StatsigUser):
